# Figure 2a calculate true GSD

rm(list=ls())

vec<-c(6,2,4,2,6,0,4,0)
GSDpoints<-matrix(data=vec,ncol=2,byrow=T)
GSDpoints<-as.data.frame(GSDpoints)
dimnames(GSDpoints)[[2]]<-c("x1","x2")
prGSDvals<-1/(1+exp(-4+GSDpoints$x1+GSDpoints$x2))
predictedGSD<-(prGSDvals[1]-prGSDvals[2])-(prGSDvals[3]-prGSDvals[4])
print(predictedGSD, quote=F)
# predictedGSD = 0.2795804

# Figure 2b calculate true GSD

rm(list=ls())

vec<-c(2,2,0,2,2,0,0,0)
GSDpoints<-matrix(data=vec,ncol=2,byrow=T)
GSDpoints<-as.data.frame(GSDpoints)
dimnames(GSDpoints)[[2]]<-c("x1","x2")
prGSDvals<-1/(1+exp(-4+GSDpoints$x1+GSDpoints$x2-0.3*GSDpoints$x1*GSDpoints$x2))
predictedGSD<-(prGSDvals[1]-prGSDvals[2])-(prGSDvals[3]-prGSDvals[4])
print(predictedGSD, quote=F)
# predictedGSD =-0.01105558

# Figure 3b calculate true GSD

rm(list=ls())

vec<-c(8,8,0,8,8,0,0,0)
GSDpoints<-matrix(data=vec,ncol=2,byrow=T)
GSDpoints<-as.data.frame(GSDpoints)
dimnames(GSDpoints)[[2]]<-c("x1","x2")
prGSDvals<-1/(1+exp(-1+0.125*GSDpoints$x1+0.125*GSDpoints$x2))
predictedGSD<-(prGSDvals[1]-prGSDvals[2])-(prGSDvals[3]-prGSDvals[4])
print(predictedGSD, quote=F)
# predictedGSD = 0


# Simulations about Figure 3b
# Start with basic simulation

rm(list=ls())
require(MASS)
require(mvtnorm)
set.seed(123456)


# do this on 100 samples
gsd.ci<-matrix(data=NA, nrow=100,ncol=2)
for(j in 1:100){
	
	# print sample that we're on
	print(c("Sample #: ",j), quote=F)

	# create a sample of 1000 cases
	x1<-runif(1000,min=0,max=8)
	x2<-runif(1000,min=0,max=8)
	random<-runif(1000, min=0, max=1)
	pry.figthreeb<-1/(1+exp(-1+0.125*x1+0.125*x2))
	y.figthreeb<-ifelse(pry.figthreeb<=random, 1, 0)

	# run a logit on the sample
	model<-glm(y.figthreeb~x1+x2,family=binomial(link="logit"))

	# create a clarify-like sampling from the betas distribution
	betas<-rmvnorm(5000, mean=coefficients(model), sigma=vcov(model))

	predictedGSD<-c()
	# calculate GSD for every draw from beta
	for(i in seq(from=1, to=dim(betas)[1], by=1)){
		vec<-c(8,8,0,8,8,0,0,0)
		GSDpoints<-matrix(data=vec,ncol=2,byrow=T)
		GSDpoints<-as.data.frame(GSDpoints)
		dimnames(GSDpoints)[[2]]<-c("x1","x2")
		prGSDvals<-1/(1+exp(betas[i,1]+betas[i,2]*GSDpoints$x1+betas[i,3]*GSDpoints$x2))
		predictedGSD[i]<-(prGSDvals[1]-prGSDvals[2])-(prGSDvals[3]-prGSDvals[4])
	}

	gsd.ci[j,]<-quantile(predictedGSD,c(.025,.975))

}

significance.count<-sum(ifelse(gsd.ci[,1]>0 | gsd.ci[,2]<0, 1,0))



# utility comparison framework (verification - not needed)

rm(list=ls())
require(MASS)
require(mvtnorm)
set.seed(123456)

# do this on 100 samples
gsd.ci<-matrix(data=NA, nrow=100,ncol=2)
for(j in 1:100){
	
	# print sample that we're on
	print(c("Sample #: ",j), quote=F)

	# create a sample of 1000 cases
	x1<-runif(1000,min=0,max=8)
	x2<-runif(1000,min=0,max=8)
	y.figthreeb<-ifelse(-1+0.125*x1+0.125*x2+rlogis(1000,location=0,scale=1)>=0, 1, 0)

	# run a logit on the sample
	model<-glm(y.figthreeb~x1+x2,family=binomial(link="logit"))

	# create a clarify-like sampling from the betas distribution
	betas<-rmvnorm(5000, mean=coefficients(model), sigma=vcov(model))

	predictedGSD<-c()
	# calculate GSD for every draw from beta
	for(i in seq(from=1, to=dim(betas)[1], by=1)){
		vvec<-c(8,8,0,8,8,0,0,0)
		GSDpoints<-matrix(data=vec,ncol=2,byrow=T)
		GSDpoints<-as.data.frame(GSDpoints)
		dimnames(GSDpoints)[[2]]<-c("x1","x2")
		prGSDvals<-1/(1+exp(betas[i,1]+betas[i,2]*GSDpoints$x1+betas[i,3]*GSDpoints$x2))
		predictedGSD[i]<-(prGSDvals[1]-prGSDvals[2])-(prGSDvals[3]-prGSDvals[4])
	}

	gsd.ci[j,]<-quantile(predictedGSD,c(.025,.975))

}


# smaller sample and correlated IVs


rm(list=ls())
require(MASS)
require(mvtnorm)
set.seed(123456)


# do this on 100 samples
gsd.ci<-matrix(data=NA, nrow=100,ncol=2)
for(j in 1:100){
	
	# print sample that we're on
	print(c("Sample #: ",j), quote=F)

	# create a sample of 500 cases, correlated at about .25
	vars<-rmvnorm(500,mean=c(4,4), sigma=array(c(4.16, 1.04, 1.04, 4.16),dim=c(2,2)))
	#vars<-rmvnorm(1000,mean=c(4,4), sigma=array(c(4.16, 2.08, 2.08, 4.16),dim=c(2,2)))
	x1<-vars[,1]
	x2<-vars[,2]
	random<-runif(500, min=0, max=1)
	pry.figthreeb<-1/(1+exp(-1+0.125*x1+0.125*x2))
	y.figthreeb<-ifelse(pry.figthreeb<=random, 1, 0)

	# run a logit on the sample
	model<-glm(y.figthreeb~x1+x2,family=binomial(link="logit"))

	# create a clarify-like sampling from the betas distribution
	betas<-rmvnorm(5000, mean=coefficients(model), sigma=vcov(model))

	predictedGSD<-c()
	# calculate GSD for every draw from beta
	for(i in seq(from=1, to=dim(betas)[1], by=1)){
		vec<-c(8,8,0,8,8,0,0,0)
		GSDpoints<-matrix(data=vec,ncol=2,byrow=T)
		GSDpoints<-as.data.frame(GSDpoints)
		dimnames(GSDpoints)[[2]]<-c("x1","x2")
		prGSDvals<-1/(1+exp(betas[i,1]+betas[i,2]*GSDpoints$x1+betas[i,3]*GSDpoints$x2))
		predictedGSD[i]<-(prGSDvals[1]-prGSDvals[2])-(prGSDvals[3]-prGSDvals[4])
	}

	gsd.ci[j,]<-quantile(predictedGSD,c(.025,.975))

}



#####################################################################

# Simulations for Figure 2a
# Start with basic simulation

rm(list=ls())
require(MASS)
require(mvtnorm)
set.seed(123456)


# do this on 100 samples
gsd.ci<-matrix(data=NA, nrow=100,ncol=2)
for(j in 1:100){
	
	# print sample that we're on
	print(c("Sample #: ",j), quote=F)

	# create a sample of 1000 cases
	x1<-runif(1000,min=0,max=8)
	x2<-runif(1000,min=0,max=8)
	random<-runif(1000, min=0, max=1)
	pry.figthreeb<-1/(1+exp(-4+x1+x2))
	y.figthreeb<-ifelse(pry.figthreeb<=random, 1, 0)

	# run a logit on the sample
	model<-glm(y.figthreeb~x1+x2,family=binomial(link="logit"))

	# create a clarify-like sampling from the betas distribution
	betas<-rmvnorm(5000, mean=coefficients(model), sigma=vcov(model))

	predictedGSD<-c()
	# calculate GSD for every draw from beta
	for(i in seq(from=1, to=dim(betas)[1], by=1)){
		vec<-c(6,2,4,2,6,0,4,0)
		GSDpoints<-matrix(data=vec,ncol=2,byrow=T)
		GSDpoints<-as.data.frame(GSDpoints)
		dimnames(GSDpoints)[[2]]<-c("x1","x2")
		prGSDvals<-1/(1+exp(betas[i,1]+betas[i,2]*GSDpoints$x1+betas[i,3]*GSDpoints$x2))
		predictedGSD[i]<-(prGSDvals[1]-prGSDvals[2])-(prGSDvals[3]-prGSDvals[4])
	}

	gsd.ci[j,]<-quantile(predictedGSD,c(.025,.975))

}

significance.count<-sum(ifelse(gsd.ci[,1]>0 | gsd.ci[,2]<0, 1,0))



#####################################################################

# Simulations for Figure 2b
# Start with basic simulation

rm(list=ls())
require(MASS)
require(mvtnorm)
set.seed(123456)


# do this on 100 samples
gsd.ci<-matrix(data=NA, nrow=100,ncol=2)
product.significant<-c()
for(j in 1:100){
	
	# print sample that we're on
	print(c("Sample #: ",j), quote=F)

	# create a sample of 1000 cases
	x1<-runif(1000,min=0,max=8)
	x2<-runif(1000,min=0,max=8)
	random<-runif(1000, min=0, max=1)
	pry.figthreeb<-1/(1+exp(-4+x1+x2-0.30*x1*x2))
	y.figthreeb<-ifelse(pry.figthreeb<=random, 1, 0)

	# run a logit on the sample
	model<-glm(y.figthreeb~x1*x2,family=binomial(link="logit"))

	# record whether the product term was significant
	product.significant[j]<-ifelse(summary(model)$coefficients[4,4]<=.05, 1, 0)

	# create a clarify-like sampling from the betas distribution
	betas<-rmvnorm(5000, mean=coefficients(model), sigma=vcov(model))

	predictedGSD<-c()
	# calculate GSD for every draw from beta
	for(i in seq(from=1, to=dim(betas)[1], by=1)){
		vec<-c(2,2,0,2,2,0,0,0)
		GSDpoints<-matrix(data=vec,ncol=2,byrow=T)
		GSDpoints<-as.data.frame(GSDpoints)
		dimnames(GSDpoints)[[2]]<-c("x1","x2")
		prGSDvals<-1/(1+exp(betas[i,1]+betas[i,2]*GSDpoints$x1+betas[i,3]*GSDpoints$x2+GSDpoints$x1*GSDpoints$x2*betas[i,4]))
		predictedGSD[i]<-(prGSDvals[1]-prGSDvals[2])-(prGSDvals[3]-prGSDvals[4])
	}

	gsd.ci[j,]<-quantile(predictedGSD,c(.025,.975))


}

significance.count<-sum(ifelse(gsd.ci[,1]>0 | gsd.ci[,2]<0, 1,0))












#####################################################################

# Simulations for Figure 3b
# Calculate second derivative errors and significances

rm(list=ls())
require(MASS)
require(mvtnorm)
set.seed(123456)
significance.count<-c()
point_DY2DXDZ<-matrix(data=NA, nrow=100, ncol=81)

# do this on 100 samples
gsd.ci<-matrix(data=NA, nrow=100,ncol=2)
for(j in 1:100){
	
	# print sample that we're on
	print(c("Sample #: ",j), quote=F)

	# create a sample of 1000 cases
	x1<-runif(1000,min=0,max=8)
	x2<-runif(1000,min=0,max=8)
	random<-runif(1000, min=0, max=1)
	pry.figthreeb<-1/(1+exp(-1+0.125*x1+0.125*x2))
	y.figthreeb<-ifelse(pry.figthreeb<=random, 1, 0)

	# run a logit on the sample
	model<-glm(y.figthreeb~x1+x2,family=binomial(link="logit"))

	# store betas
	point.est.betas<-coefficients(model)

	# calculate second derivative for every beta draw
	temp<-seq(from=0, to=8,by=1)
	predictpoints<-c(rep(temp,1,each=length(temp)),rep(temp,length(temp),each=1))
	predictpoints<-matrix(data=predictpoints,ncol=2,byrow=FALSE)
	dimnames(predictpoints)[[2]]<-c("x1","x2")
	predictpoints<-as.data.frame(predictpoints)
	predicted_DY2DXDZ<-matrix(data=NA, nrow=5000, ncol=81)

	# start with the point estimates
	predictpointsnew<-predictpoints
	predictpointsnew[,2]<-predictpointsnew[,2]+.0005
	predictpointsX<-predictpointsnew
	predictpointsX[,1]<-predictpointsX[,1]+.0005
	predictedXtwo<-1/(1+exp(point.est.betas[1]+point.est.betas[2]*predictpointsX$x1+point.est.betas[3]*predictpointsX$x2))
	predictpointsX<-predictpointsnew
	predictpointsX[,1]<-predictpointsX[,1]-.0005
	predictedXone<-1/(1+exp(point.est.betas[1]+point.est.betas[2]*predictpointsX$x1+point.est.betas[3]*predictpointsX$x2))
	predictedDYDX_highz<-(predictedXtwo-predictedXone)/(.001)

	predictpointsnew<-predictpoints
	predictpointsnew[,2]<-predictpointsnew[,2]-.0005
	predictpointsX<-predictpointsnew
	predictpointsX[,1]<-predictpointsX[,1]+.0005
	predictedXtwo<-1/(1+exp(point.est.betas[1]+point.est.betas[2]*predictpointsX$x1+point.est.betas[3]*predictpointsX$x2))
	predictpointsX<-predictpointsnew
	predictpointsX[,1]<-predictpointsX[,1]-.0005
	predictedXone<-1/(1+exp(point.est.betas[1]+point.est.betas[2]*predictpointsX$x1+point.est.betas[3]*predictpointsX$x2))
	predictedDYDX_lowz<-(predictedXtwo-predictedXone)/(.001)

	point_DY2DXDZ[j,]<-(predictedDYDX_highz-predictedDYDX_lowz)/.001

	# create a clarify-like sampling from the betas distribution
	betas<-rmvnorm(5000, mean=coefficients(model), sigma=vcov(model))
	
	# now do the clarify samples
	for(i in seq(from=1, to=dim(betas)[1], by=1)){

		predictpointsnew<-predictpoints
		predictpointsnew[,2]<-predictpointsnew[,2]+.0005
		predictpointsX<-predictpointsnew
		predictpointsX[,1]<-predictpointsX[,1]+.0005
		predictedXtwo<-1/(1+exp(betas[i,1]+betas[i,2]*predictpointsX$x1+betas[i,3]*predictpointsX$x2))
		predictpointsX<-predictpointsnew
		predictpointsX[,1]<-predictpointsX[,1]-.0005
		predictedXone<-1/(1+exp(betas[i,1]+betas[i,2]*predictpointsX$x1+betas[i,3]*predictpointsX$x2))
		predictedDYDX_highz<-(predictedXtwo-predictedXone)/(.001)

		predictpointsnew<-predictpoints
		predictpointsnew[,2]<-predictpointsnew[,2]-.0005
		predictpointsX<-predictpointsnew
		predictpointsX[,1]<-predictpointsX[,1]+.0005
		predictedXtwo<-1/(1+exp(betas[i,1]+betas[i,2]*predictpointsX$x1+betas[i,3]*predictpointsX$x2))
		predictpointsX<-predictpointsnew
		predictpointsX[,1]<-predictpointsX[,1]-.0005
		predictedXone<-1/(1+exp(betas[i,1]+betas[i,2]*predictpointsX$x1+betas[i,3]*predictpointsX$x2))
		predictedDYDX_lowz<-(predictedXtwo-predictedXone)/(.001)
	
		predicted_DY2DXDZ[i,]<-(predictedDYDX_highz-predictedDYDX_lowz)/.001

	}

	# form a confidence interval of the 5000 beta draws for each of the 81 points, see if it includes zero
	sd.ci.lo<-c()
	sd.ci.hi<-c()
	for(i in 1:81){

		sd.ci.lo[i]<-quantile(predicted_DY2DXDZ[,i], .025)
		sd.ci.hi[i]<-quantile(predicted_DY2DXDZ[,i], .975)

	}
	
	# count how many CIs are significant
	significance.count[j]<-sum(ifelse(sd.ci.lo>0 | sd.ci.hi<0, 1,0))
	
	# export CIs for all 81 points
	output<-cbind(predictpoints,sd.ci.lo,sd.ci.hi)
	dimnames(output)[[2]]<-c("x1","x2","lo.ci", "hi.ci")
	write.csv(output, file=paste("Sample",j, "Second Derivative CIs"), quote=F)


}

sum(significance.count)
# export a list of all point estimate derivative values
write.csv(point_DY2DXDZ, file=paste("Point Estimate Second Derivatives, in Sample Order"), quote=F)
















#####################################################################

# Simulations for Figure 2a
# Calculate second derivative errors and significances



rm(list=ls())
require(MASS)
require(mvtnorm)
set.seed(123456)
significance.count<-c()

# do this on 100 samples
gsd.ci<-matrix(data=NA, nrow=100,ncol=2)

for(j in 1:100){
	
	# print sample that we're on
	print(c("Sample #: ",j), quote=F)

	# create a sample of 1000 cases
	x1<-runif(1000,min=0,max=8)
	x2<-runif(1000,min=0,max=8)
	random<-runif(1000, min=0, max=1)
	pry.figthreeb<-1/(1+exp(-4+x1+x2))
	y.figthreeb<-ifelse(pry.figthreeb<=random, 1, 0)

	# run a logit on the sample
	model<-glm(y.figthreeb~x1+x2,family=binomial(link="logit"))

	# create a clarify-like sampling from the betas distribution
	betas<-rmvnorm(5000, mean=coefficients(model), sigma=vcov(model))
	
	# calculate second derivative for every beta draw
	temp<-seq(from=0, to=8,by=1)
	predictpoints<-c(5,1)
	predictpoints<-matrix(data=predictpoints,ncol=2,byrow=FALSE)
	dimnames(predictpoints)[[2]]<-c("x1","x2")
	predictpoints<-as.data.frame(predictpoints)
	predicted_DY2DXDZ<-c()

	for(i in seq(from=1, to=dim(betas)[1], by=1)){

		predictpointsnew<-predictpoints
		predictpointsnew[,2]<-predictpointsnew[,2]+.0005
		predictpointsX<-predictpointsnew
		predictpointsX[,1]<-predictpointsX[,1]+.0005
		predictedXtwo<-1/(1+exp(betas[i,1]+betas[i,2]*predictpointsX$x1+betas[i,3]*predictpointsX$x2))
		predictpointsX<-predictpointsnew
		predictpointsX[,1]<-predictpointsX[,1]-.0005
		predictedXone<-1/(1+exp(betas[i,1]+betas[i,2]*predictpointsX$x1+betas[i,3]*predictpointsX$x2))
		predictedDYDX_highz<-(predictedXtwo-predictedXone)/(.001)

		predictpointsnew<-predictpoints
		predictpointsnew[,2]<-predictpointsnew[,2]-.0005
		predictpointsX<-predictpointsnew
		predictpointsX[,1]<-predictpointsX[,1]+.0005
		predictedXtwo<-1/(1+exp(betas[i,1]+betas[i,2]*predictpointsX$x1+betas[i,3]*predictpointsX$x2))
		predictpointsX<-predictpointsnew
		predictpointsX[,1]<-predictpointsX[,1]-.0005
		predictedXone<-1/(1+exp(betas[i,1]+betas[i,2]*predictpointsX$x1+betas[i,3]*predictpointsX$x2))
		predictedDYDX_lowz<-(predictedXtwo-predictedXone)/(.001)
	
		predicted_DY2DXDZ[i]<-(predictedDYDX_highz-predictedDYDX_lowz)/.001

	}

	# form a confidence interval of the 5000 beta draws for point (5,1) , see if it includes zero

	sd.ci.lo<-quantile(predicted_DY2DXDZ, .025)
	sd.ci.hi<-quantile(predicted_DY2DXDZ, .975)
	
	# count how many CIs are significant
	significance.count[j]<-sum(ifelse(sd.ci.lo>0 | sd.ci.hi<0, 1,0))

	output<-cbind(predictpoints,sd.ci.lo,sd.ci.hi)
	if(j==1){f.output<-output; dimnames(f.output)[[2]]<-c("x1","x2","lo.ci", "hi.ci")}
	else{dimnames(output)[[2]]<-c("x1","x2","lo.ci", "hi.ci"); f.output<-rbind(f.output,output)}

}

write.csv(f.output, file=paste("Figure 2a Second Derivative CIs"), quote=F)
sum(significance.count)



