clear
set more off
set mem 300m
set seed 08220703
use "scobit.dta"

log using "ClarifyRepofWR.log", replace

*drop missing vote values
drop if(newvote==-1)

estsimp probit newvote closing neweduc educ2 age age2 south gov

*Education = min 
setx  neweduc min educ2 min age mean age2 mean south 0 gov 0 
simqi, fd(prval(1)) changex(closing mean 0)

*Education = max
setx  neweduc max educ2 max age mean age2 mean south 0 gov 0 
simqi, fd(prval(1)) changex(closing mean 0)

*Education = 5 (mode)
setx  neweduc 5 educ2 25 age mean age2 mean south 0 gov 0 
simqi, fd(prval(1)) changex(closing mean 0)

*Difference education min to max
setx  neweduc min educ2 min age mean age2 mean south 0 gov 0 closing mean
simqi, prval(1) genpr(edminclosemean)
setx  neweduc min educ2 min age mean age2 mean south 0 gov 0 closing 0
simqi, prval(1) genpr(edminclosezero)
setx  neweduc max educ2 max age mean age2 mean south 0 gov 0 closing mean
simqi, prval(1) genpr(edmaxclosemean)
setx  neweduc max educ2 max age mean age2 mean south 0 gov 0 closing 0
simqi, prval(1) genpr(edmaxclosezero)
setx  neweduc 5 educ2 25 age mean age2 mean south 0 gov 0 closing mean
simqi, prval(1) genpr(edmodeclosemean)
setx  neweduc 5 educ2 25 age mean age2 mean south 0 gov 0 closing 0
simqi, prval(1) genpr(edmodeclosezero)

*calculate FD (closing=mean to closing=0) for every value of education

*ed=1
setx  neweduc 1 educ2 1 age mean age2 mean south 0 gov 0 closing mean
simqi, prval(1) genpr(edoneclosemean)
setx  neweduc 1 educ2 1 age mean age2 mean south 0 gov 0 closing 0
simqi, prval(1) genpr(edoneclosezero)

*ed=2
setx  neweduc 2 educ2 4 age mean age2 mean south 0 gov 0 closing mean
simqi, prval(1) genpr(edtwoclosemean)
setx  neweduc 2 educ2 4 age mean age2 mean south 0 gov 0 closing 0
simqi, prval(1) genpr(edtwoclosezero)

*ed=3
setx  neweduc 3 educ2 9 age mean age2 mean south 0 gov 0 closing mean
simqi, prval(1) genpr(edthreeclosemean)
setx  neweduc 3 educ2 9 age mean age2 mean south 0 gov 0 closing 0
simqi, prval(1) genpr(edthreeclosezero)

*ed=4
setx  neweduc 4 educ2 16 age mean age2 mean south 0 gov 0 closing mean
simqi, prval(1) genpr(edfourclosemean)
setx  neweduc 4 educ2 16 age mean age2 mean south 0 gov 0 closing 0
simqi, prval(1) genpr(edfourclosezero)

*ed=5
setx  neweduc 5 educ2 25 age mean age2 mean south 0 gov 0 closing mean
simqi, prval(1) genpr(edfiveclosemean)
setx  neweduc 5 educ2 25 age mean age2 mean south 0 gov 0 closing 0
simqi, prval(1) genpr(edfiveclosezero)

*ed=6
setx  neweduc 6 educ2 36 age mean age2 mean south 0 gov 0 closing mean
simqi, prval(1) genpr(edsixclosemean)
setx  neweduc 6 educ2 36 age mean age2 mean south 0 gov 0 closing 0
simqi, prval(1) genpr(edsixclosezero)

*ed=7
setx  neweduc 7 educ2 49 age mean age2 mean south 0 gov 0 closing mean
simqi, prval(1) genpr(edsevenclosemean)
setx  neweduc 7 educ2 49 age mean age2 mean south 0 gov 0 closing 0
simqi, prval(1) genpr(edsevenclosezero)

*ed=8
setx  neweduc 8 educ2 64 age mean age2 mean south 0 gov 0 closing mean
simqi, prval(1) genpr(edeightclosemean)
setx  neweduc 8 educ2 64 age mean age2 mean south 0 gov 0 closing 0
simqi, prval(1) genpr(edeightclosezero)


* changes in voting behavior as closing moves from mean to zero
* for various values of education

*ed = max, min and mode
gen fd_edmax = edmaxclosezero - edmaxclosemean
gen fd_edmin = edminclosezero - edminclosemean
gen fd_edmode = edmodeclosezero - edmodeclosemean

* ed = all values
gen fd_one = edoneclosezero - edoneclosemean
gen fd_two = edtwoclosezero - edtwoclosemean
gen fd_three = edthreeclosezero - edthreeclosemean
gen fd_four = edfourclosezero - edfourclosemean
gen fd_five = edfiveclosezero - edfiveclosemean
gen fd_six = edsixclosezero - edsixclosemean
gen fd_seven = edsevenclosezero - edsevenclosemean
gen fd_eight = edeightclosezero - edeightclosemean

*report differences
* ed= max, min and mode first
centile fd_edmax, centile(2.5 97.5)
mean fd_edmax

centile fd_edmin, centile(2.5 97.5)
mean fd_edmin

centile fd_edmode, centile(2.5 97.5)
mean fd_edmode

* now all values of ed

centile fd_one, centile(2.5 97.5)
mean fd_one
centile fd_two, centile(2.5 97.5)
mean fd_two
centile fd_three, centile(2.5 97.5)
mean fd_three
centile fd_four, centile(2.5 97.5)
mean fd_four
centile fd_five, centile(2.5 97.5)
mean fd_five
centile fd_six, centile(2.5 97.5)
mean fd_six
centile fd_seven, centile(2.5 97.5)
mean fd_seven
centile fd_eight, centile(2.5 97.5)
mean fd_eight

* calculate changes in the effect of closing date
* as education changes

*min, max, and mode comparisons
gen sec_dif = fd_edmin - fd_edmax
gen sec_dif_two = fd_edmode - fd_edmax
gen sec_dif_three = fd_edmin - fd_edmode

centile sec_dif, centile(2.5 97.5)
mean sec_dif

centile sec_dif_two, centile(2.5 97.5)
mean sec_dif_two

centile sec_dif_three, centile(2.5 97.5)
mean sec_dif_three


* comparisons for maximum effect vs. extremes
* of education
gen sec_dif_four = fd_one - fd_three
gen sec_dif_five = fd_three - fd_eight

centile sec_dif_four, centile(2.5 97.5)
mean sec_dif_four

centile sec_dif_five, centile(2.5 97.5)
mean sec_dif_five


* comparisons around the maximum effect of ed

gen sec_dif_six = fd_one - fd_two
gen sec_dif_seven = fd_two - fd_eight

centile sec_dif_six, centile(2.5 97.5)
mean sec_dif_six

centile sec_dif_seven, centile(2.5 97.5)
mean sec_dif_seven

gen sec_dif_eight = fd_one - fd_four
gen sec_dif_nine = fd_four - fd_eight

centile sec_dif_eight, centile(2.5 97.5)
mean sec_dif_eight

centile sec_dif_nine, centile(2.5 97.5)
mean sec_dif_nine

gen sec_dif_ten = fd_one - fd_five
gen sec_dif_eleven = fd_five - fd_eight

centile sec_dif_ten, centile(2.5 97.5)
mean sec_dif_ten

centile sec_dif_eleven, centile(2.5 97.5)
mean sec_dif_eleven


* calculate second differences that compare [the response of the probability of voting to a change in the variable closing from its mean value to zero] across two different values of the variable, neweduc.  

* the variable fd_### indicates the first difference measuring the response of the probability of voting to a change in the variable closing from its mean value to zero when neweduc has a score of ###

* the variable sec_diff_#1_#2 indicates the second difference that compares [the response of the probability of voting to a change in the variable closing from its mean value to zero] when neweduc = #2 to the same response when neweduc = #1 

gen sec_dif_1_3 = fd_three - fd_one
gen sec_dif_8_3 = fd_three - fd_eight
gen sec_dif_1_4 = fd_four - fd_one
gen sec_dif_2_4 = fd_four - fd_two
gen sec_dif_1_2 = fd_two - fd_one
gen sec_dif_2_3 = fd_three - fd_two
gen sec_dif_3_4 = fd_four - fd_three
gen sec_dif_4_5 = fd_five - fd_four
gen sec_dif_5_6 = fd_six - fd_five
gen sec_dif_6_7 = fd_seven - fd_six
gen sec_dif_7_8 = fd_eight - fd_seven

centile sec_dif_1_3, centile(2.5 97.5)
mean sec_dif_1_3
centile sec_dif_8_3, centile(2.5 97.5)
mean sec_dif_8_3
centile sec_dif_1_4, centile(2.5 97.5)
mean sec_dif_1_4
centile sec_dif_2_4, centile(2.5 97.5)
mean sec_dif_2_4
centile sec_dif_1_2, centile(2.5 97.5)
mean sec_dif_1_2
centile sec_dif_2_3, centile(2.5 97.5)
mean sec_dif_2_3
centile sec_dif_3_4, centile(2.5 97.5)
mean sec_dif_3_4
centile sec_dif_4_5, centile(2.5 97.5)
mean sec_dif_4_5
centile sec_dif_5_6, centile(2.5 97.5)
mean sec_dif_5_6
centile sec_dif_6_7, centile(2.5 97.5)
mean sec_dif_6_7
centile sec_dif_7_8, centile(2.5 97.5)
mean sec_dif_7_8













* Use Nagler's Model

clear
set more off
set mem 300m
set seed 08220703
use "scobit.dta"

*drop missing vote values
drop if(newvote==-1)

* test for product term significances

probit newvote closing neweduc educ2 cloeduc cloeduc2 age age2 south gov
est store A
probit newvote closing neweduc educ2 age age2 south gov
est store B
lrtest A B

probit newvote closing neweduc educ2 cloeduc age age2 south gov


estsimp probit newvote closing neweduc educ2 cloeduc cloeduc2 age age2 south gov

*Education = min 
setx  neweduc min educ2 min age mean age2 mean south 0 gov 0
simqi, fd(prval(1)) changex(closing mean 0 cloeduc 24.79075 0 cloeduc2 24.79075 0)

*Education = max
setx  neweduc max educ2 max age mean age2 mean south 0 gov 0 
simqi, fd(prval(1)) changex(closing mean 0 cloeduc 198.326 0 cloeduc2 1586.608 0)

*Difference education min to max and min to mode
setx  neweduc min educ2 min age mean age2 mean south 0 gov 0 closing mean cloeduc 24.79075 cloeduc2 24.79075
simqi, prval(1) genpr(edminclosemean)
setx  neweduc min educ2 min age mean age2 mean south 0 gov 0 closing 0 cloeduc 0 cloeduc2 0
simqi, prval(1) genpr(edminclosezero)
setx  neweduc max educ2 max age mean age2 mean south 0 gov 0 closing mean cloeduc 198.326 cloeduc2 1586.608
simqi, prval(1) genpr(edmaxclosemean)
setx  neweduc max educ2 max age mean age2 mean south 0 gov 0 closing 0 cloeduc 0 cloeduc2 0
simqi, prval(1) genpr(edmaxclosezero)
setx  neweduc 5 educ2 25 age mean age2 mean south 0 gov 0 closing mean cloeduc 124.7323 cloeduc2 623.6615
simqi, prval(1) genpr(edmodeclosemean)
setx  neweduc 5 educ2 25 age mean age2 mean south 0 gov 0 closing 0 cloeduc 0 cloeduc2 0
simqi, prval(1) genpr(edmodeclosezero)

*calculate FD (closing=mean to closing=0) for every value of education

*ed=1
setx  neweduc 1 educ2 1 age mean age2 mean south 0 gov 0 closing mean cloeduc 24.79075 cloeduc2 24.79075
simqi, prval(1) genpr(edoneclosemean)
setx  neweduc 1 educ2 1 age mean age2 mean south 0 gov 0 closing 0 cloeduc 0 cloeduc2 0
simqi, prval(1) genpr(edoneclosezero)

*ed=2
setx  neweduc 2 educ2 4 age mean age2 mean south 0 gov 0 closing mean cloeduc 49.5815 cloeduc2 99.163
simqi, prval(1) genpr(edtwoclosemean)
setx  neweduc 2 educ2 4 age mean age2 mean south 0 gov 0 closing 0 cloeduc 0 cloeduc2 0
simqi, prval(1) genpr(edtwoclosezero)

*ed=3
setx  neweduc 3 educ2 9 age mean age2 mean south 0 gov 0 closing mean cloeduc 74.37225 cloeduc2 223.1167
simqi, prval(1) genpr(edthreeclosemean)
setx  neweduc 3 educ2 9 age mean age2 mean south 0 gov 0 closing 0 cloeduc 0 cloeduc2 0
simqi, prval(1) genpr(edthreeclosezero)

*ed=4
setx  neweduc 4 educ2 16 age mean age2 mean south 0 gov 0 closing mean cloeduc 99.163 cloeduc2 396.652
simqi, prval(1) genpr(edfourclosemean)
setx  neweduc 4 educ2 16 age mean age2 mean south 0 gov 0 closing 0 cloeduc 0 cloeduc2 0
simqi, prval(1) genpr(edfourclosezero)

*ed=5
setx  neweduc 5 educ2 25 age mean age2 mean south 0 gov 0 closing mean cloeduc 123.9537 cloeduc2 619.7687
simqi, prval(1) genpr(edfiveclosemean)
setx  neweduc 5 educ2 25 age mean age2 mean south 0 gov 0 closing 0 cloeduc 0 cloeduc2 0
simqi, prval(1) genpr(edfiveclosezero)

*ed=6
setx  neweduc 6 educ2 36 age mean age2 mean south 0 gov 0 closing mean cloeduc 148.7445 cloeduc2 892.467
simqi, prval(1) genpr(edsixclosemean)
setx  neweduc 6 educ2 36 age mean age2 mean south 0 gov 0 closing 0 cloeduc 0 cloeduc2 0
simqi, prval(1) genpr(edsixclosezero)

*ed=7
setx  neweduc 7 educ2 49 age mean age2 mean south 0 gov 0 closing mean cloeduc 173.5352 cloeduc2 1214.747
simqi, prval(1) genpr(edsevenclosemean)
setx  neweduc 7 educ2 49 age mean age2 mean south 0 gov 0 closing 0 cloeduc 0 cloeduc2 0
simqi, prval(1) genpr(edsevenclosezero)

*ed=8
setx  neweduc 8 educ2 64 age mean age2 mean south 0 gov 0 closing mean cloeduc 198.326 cloeduc2 1586.608
simqi, prval(1) genpr(edeightclosemean)
setx  neweduc 8 educ2 64 age mean age2 mean south 0 gov 0 closing 0 cloeduc 0 cloeduc2 0
simqi, prval(1) genpr(edeightclosezero)

* ed = all values
gen fd_one = edoneclosezero - edoneclosemean
gen fd_two = edtwoclosezero - edtwoclosemean
gen fd_three = edthreeclosezero - edthreeclosemean
gen fd_four = edfourclosezero - edfourclosemean
gen fd_five = edfiveclosezero - edfiveclosemean
gen fd_six = edsixclosezero - edsixclosemean
gen fd_seven = edsevenclosezero - edsevenclosemean
gen fd_eight = edeightclosezero - edeightclosemean

* now all values of ed

centile fd_one, centile(2.5 97.5)
mean fd_one
centile fd_two, centile(2.5 97.5)
mean fd_two
centile fd_three, centile(2.5 97.5)
mean fd_three
centile fd_four, centile(2.5 97.5)
mean fd_four
centile fd_five, centile(2.5 97.5)
mean fd_five
centile fd_six, centile(2.5 97.5)
mean fd_six
centile fd_seven, centile(2.5 97.5)
mean fd_seven
centile fd_eight, centile(2.5 97.5)
mean fd_eight

*recapitulate earlier analysis
gen fd_edmax = edmaxclosezero - edmaxclosemean
gen fd_edmin = edminclosezero - edminclosemean
gen fd_edmode = edmodeclosezero - edmodeclosemean

centile fd_edmax, centile(2.5 97.5)
mean fd_edmax

centile fd_edmin, centile(2.5 97.5)
mean fd_edmin

centile fd_edmode, centile(2.5 97.5)
mean fd_edmode

gen sec_dif = fd_edmin - fd_edmax
gen sec_dif_two = fd_edmode - fd_edmax
gen sec_dif_three = fd_edmin - fd_edmode

centile sec_dif, centile(2.5 97.5)
mean sec_dif

centile sec_dif_two, centile(2.5 97.5)
mean sec_dif_two

centile sec_dif_three, centile(2.5 97.5)
mean sec_dif_three

log close




















